@@ -220,6 +220,13 @@ gvc_stream_collate (GvcMixerStream *a,
         namea = gvc_mixer_stream_get_name (a);
         nameb = gvc_mixer_stream_get_name (b);
 
+        if (nameb == NULL && namea == NULL)
+        	return 0;
+        if (nameb == NULL)
+        	return 1;
+        if (namea == NULL)
+        	return -1;
+
         return g_utf8_collate (namea, nameb);
 }
 
@@ -506,11 +513,6 @@ update_sink (GvcMixerControl    *control,
                  map_buff);
 #endif
 
-        /* for now completely ignore virtual streams */
-        if (!(info->flags & PA_SINK_HARDWARE)) {
-                return;
-        }
-
         is_new = FALSE;
         stream = g_hash_table_lookup (control->priv->sinks,
                                       GUINT_TO_POINTER (info->index));
@@ -566,8 +568,8 @@ update_source (GvcMixerControl      *control,
                  info->description);
 #endif
 
-        /* for now completely ignore virtual streams */
-        if (!(info->flags & PA_SOURCE_HARDWARE)) {
+        /* completely ignore monitors, they're not real sources */
+        if (info->monitor_of_sink != PA_INVALID_INDEX) {
                 return;
         }
 
@@ -678,6 +680,17 @@ set_is_event_stream_from_proplist (GvcMixerStream *stream,
         gvc_mixer_stream_set_is_event_stream (stream, is_event_stream);
 }
 
+static void
+set_application_id_from_proplist (GvcMixerStream *stream,
+                                  pa_proplist    *l)
+{
+        const char *t;
+
+        if ((t = pa_proplist_gets (l, PA_PROP_APPLICATION_ID))) {
+                gvc_mixer_stream_set_application_id (stream, t);
+        }
+}
+
 static void
 update_sink_input (GvcMixerControl          *control,
                    const pa_sink_input_info *info)
@@ -716,6 +729,7 @@ update_sink_input (GvcMixerControl          *control,
         gvc_mixer_stream_set_name (stream, name);
         gvc_mixer_stream_set_description (stream, info->name);
 
+        set_application_id_from_proplist (stream, info->proplist);
         set_is_event_stream_from_proplist (stream, info->proplist);
         set_icon_name_from_proplist (stream, info->proplist, "applications-multimedia");
         gvc_mixer_stream_set_volume (stream, (guint)max_volume);
@@ -763,7 +777,9 @@ update_source_output (GvcMixerControl             *control,
 
         gvc_mixer_stream_set_name (stream, name);
         gvc_mixer_stream_set_description (stream, info->name);
-        set_icon_name_from_proplist (stream, info->proplist, "applications-multimedia");
+        set_application_id_from_proplist (stream, info->proplist);
+        set_is_event_stream_from_proplist (stream, info->proplist);
+        set_icon_name_from_proplist (stream, info->proplist, "audio-input-microphone");
 
         if (is_new) {
                 g_hash_table_insert (control->priv->source_outputs,
