@@ -40,7 +40,6 @@
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 #include <gtk/gtk.h>
-#include <libgnome/gnome-help.h>
 #include <gconf/gconf-client.h>
 #include <gst/gst.h>
 #include <gst/interfaces/mixer.h>
@@ -1211,7 +1210,9 @@ help_contents_cb (GtkAction *action,
 {
 	GError *error = NULL;
 
-	gnome_help_display ("gnome-sound-recorder.xml", NULL, &error);
+	gtk_show_uri (gtk_window_get_screen (GTK_WINDOW (window)),
+		      "ghelp:gnome-sound-recorder",
+		      gtk_get_current_event_time (), &error);
 
 	if (error != NULL)
 	{
@@ -1299,7 +1300,7 @@ stop_cb (GtkAction *action,
 		set_pipeline_state_to_null (priv->record->pipeline);
 		gtk_widget_set_sensitive (window->priv->level, FALSE);
 		gtk_widget_set_sensitive (window->priv->volume_label, FALSE);
-		gtk_progress_set_percentage (GTK_PROGRESS (window->priv->level), 0);
+		gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (window->priv->level), 0.0);
 	}
 }
 
@@ -1394,12 +1395,13 @@ play_tick_callback (GSRWindow *window)
 		window->priv->len_secs = val / GST_SECOND;
 
 		len_str = seconds_to_full_string (window->priv->len_secs);
-		gtk_label_set (GTK_LABEL (window->priv->length_label), len_str);
+		gtk_label_set_text (GTK_LABEL (window->priv->length_label),
+				    len_str);
 		g_free (len_str);
 	} else {
 		if (window->priv->get_length_attempts <= 0) {
 			/* Attempts to get length ran out. */
-			gtk_label_set (GTK_LABEL (window->priv->length_label), _("Unknown"));
+			gtk_label_set_text (GTK_LABEL (window->priv->length_label), _("Unknown"));
 		} else {
 			--window->priv->get_length_attempts;
 		}
@@ -1458,7 +1460,8 @@ record_tick_callback (GSRWindow *window)
 		
 		len_str = seconds_to_full_string (secs);
 		window->priv->len_secs = secs;
-		gtk_label_set (GTK_LABEL (window->priv->length_label), len_str);
+		gtk_label_set_text (GTK_LABEL (window->priv->length_label),
+				    len_str);
 		g_free (len_str);
 	} else {
 		GST_DEBUG ("failed to query position");
@@ -1706,6 +1709,8 @@ record_start (gpointer user_data)
 	GSRWindow *window = GSR_WINDOW (user_data);
 	gchar *name;
 
+	g_assert (window->priv->tick_id == 0);
+
 	window->priv->get_length_attempts = 16;
 	window->priv->tick_id = g_timeout_add (200, (GSourceFunc) record_tick_callback, window);
 
@@ -1964,7 +1969,7 @@ level_message_handler_cb (GstBus * bus, GstMessage * message, GSRWindow *window)
 	myind = exp (peak_dB / 20);
 	if (myind > 1.0)
 		myind = 1.0;
-	gtk_progress_set_percentage (GTK_PROGRESS (priv->level), myind);
+	gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (priv->level), myind);
       }
     }
   }
@@ -2555,7 +2560,8 @@ gsr_window_set_property (GObject      *object,
 
 		utf8_name = g_filename_to_utf8 (short_name, -1, NULL, NULL, NULL);
 		if (priv->name_label != NULL) {
-			gtk_label_set (GTK_LABEL (priv->name_label), utf8_name);
+			gtk_label_set_text (GTK_LABEL (priv->name_label),
+					    utf8_name);
 		}
 
 		gsr_add_recent (priv->filename);
@@ -2621,6 +2627,7 @@ gsr_window_finalize (GObject *object)
 
 	if (priv->tick_id > 0) { 
 		g_source_remove (priv->tick_id);
+		window->priv->play->tick_id = 0;
 	}
 
 	if (priv->record_id > 0) {
